Documentation
¶
Overview ¶
Package dpresponse ...
Package dpresponse ...
Package dpresponse ...
Package dpresponse ...
Package dpresponse ...
Index ¶
- Variables
- func SetErrorResponse(ctx iris.Context, err string, statusCode int32)
- type Device
- type EmbQueue
- type Error
- type ErrorResponse
- type EventMessageBus
- type Link
- type Login
- type Manager
- type ManagerStatus
- type ManagersCollection
- type MsgExtendedInfo
- type PluginResponse
- type PluginStatusResponse
- type Status
Constants ¶
This section is empty.
Variables ¶
var ( // ServerToken is the token generated by odimra ServerToken string // PluginToken is the token generated by Plugin PluginToken string )
Functions ¶
Types ¶
type Device ¶
type Device struct {
ServerIP string `json:"ServerIP"`
Username string `json:"Username"`
DeviceUUID string `json:"device_UUID"`
}
Device struct definition
type EmbQueue ¶
type EmbQueue struct {
QueueName string `json:"EmbQueueName"`
QueueDesc string `json:"EmbQueueDesc"`
}
EmbQueue holds the information of Queue Name and Queue Description
type Error ¶
type Error struct {
Code string `json:"Code"`
Message string `json:"Message"`
MessageExtendedInfo []MsgExtendedInfo `json:"@Message.ExtendedInfo"`
}
Error struct is standard response struct
type ErrorResponse ¶
type ErrorResponse struct {
Error Error `json:"Error"`
}
ErrorResponse struct is response Error struct
func CreateErrorResponse ¶
func CreateErrorResponse(errs string) ErrorResponse
CreateErrorResponse will accepts the error string and create standard error response
type EventMessageBus ¶
type EventMessageBus struct {
EmbType string `json:"EmbType"`
EmbQueue []EmbQueue `json:"EmbQueue"`
}
EventMessageBus holds the information of EMB Broker type and EMBQueue information
type Manager ¶
type Manager struct {
OdataContext string `json:"@odata.context"`
Etag string `json:"@odata.etag,omitempty"`
OdataID string `json:"@odata.id"`
OdataType string `json:"@odata.type"`
Name string `json:"Name"`
ManagerType string `json:"ManagerType"`
ID string `json:"Id"`
UUID string `json:"UUID"`
FirmwareVersion string `json:"FirmwareVersion"`
Status *ManagerStatus `json:"Status,omitempty"`
}
Manager struct for manager deta
type ManagerStatus ¶
type ManagerStatus struct {
State string `json:"State"`
}
ManagerStatus struct is to define the status of the manager
type ManagersCollection ¶
type ManagersCollection struct {
OdataContext string `json:"@odata.context"`
Etag string `json:"@odata.etag,omitempty"`
OdataID string `json:"@odata.id"`
OdataType string `json:"@odata.type"`
Description string `json:"Description"`
Name string `json:"Name"`
Members []Link `json:"Members"`
MembersCount int `json:"Members@odata.count"`
}
ManagersCollection for Plugin
type MsgExtendedInfo ¶
type MsgExtendedInfo struct {
MessageID string `json:"MessageId"`
Message string `json:"Message"`
MessageArgs []string `json:"MessageArgs"`
}
MsgExtendedInfo struct definition
type PluginResponse ¶
PluginResponse struct definition
type PluginStatusResponse ¶
type PluginStatusResponse struct {
Comment string `json:"_comment"`
Name string `json:"Name"`
Version string `json:"Version"`
Status Status `json:"Status"`
EventMessageBus EventMessageBus `json:"EventMessageBus"`
}
PluginStatusResponse holds the information of response of PluginStatus