Documentation
¶
Overview ¶
Package rfpresponse ...
Package rfpresponse ...
Package rfpresponse ...
Package rfpresponse ...
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ServerToken is the token generated by odimra ServerToken string // PluginToken is the token generated by Plugin PluginToken string )
Functions ¶
Types ¶
type Device ¶
type Device struct {
ServerIP string `json:"ServerIP"`
Username string `json:"Username"`
DeviceUUID string `json:"device_UUID"`
}
Device struct definition
type EmbQueue ¶
type EmbQueue struct {
QueueName string `json:"EmbQueueName"`
QueueDesc string `json:"EmbQueueDesc"`
}
EmbQueue holds the information of Queue Name and Queue Description
type Error ¶
type Error struct {
Code string `json:"Code"`
Message string `json:"Message"`
MessageExtendedInfo []MsgExtendedInfo `json:"@Message.ExtendedInfo"`
}
Error struct is standard response struct
type ErrorResopnse ¶
type ErrorResopnse struct {
Error Error `json:"Error"`
}
ErrorResopnse struct is response Error struct
func CreateErrorResponse ¶
func CreateErrorResponse(errs string) ErrorResopnse
CreateErrorResponse will accrpts the error string and create standard error resopnse
type EventMessageBus ¶
type EventMessageBus struct {
EmbType string `json:"EmbType"`
EmbQueue []EmbQueue `json:"EmbQueue"`
}
EventMessageBus holds the information of EMB Broker type and EMBQueue information
type MsgExtendedInfo ¶
type MsgExtendedInfo struct {
MessageID string `json:"MessageId"`
Message string `json:"Message"`
MessageArgs []string `json:"MessageArgs"`
}
MsgExtendedInfo struct definition
type PluginResponse ¶
PluginResponse struct definition
type PluginStatusResponse ¶
type PluginStatusResponse struct {
Comment string `json:"_comment"`
Name string `json:"Name"`
Version string `json:"Version"`
Status Status `json:"Status"`
EventMessageBus EventMessageBus `json:"EventMessageBus"`
}
PluginStatusResponse holds the information of response of PluginStatus
Click to show internal directories.
Click to hide internal directories.